@@ -1,10 +1,10 @@
 /* block/test.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -196,20 +196,35 @@ main (void)
 
   gsl_set_error_handler (&my_error_handler);
 
-  test_trap ();
-  test_float_trap ();
-  test_long_double_trap ();
-  test_ulong_trap ();
-  test_long_trap ();
-  test_uint_trap ();
-  test_int_trap ();
-  test_ushort_trap ();
-  test_short_trap ();
-  test_uchar_trap ();
-  test_char_trap ();
-  test_complex_trap ();
-  test_complex_float_trap ();
-  test_complex_long_double_trap ();
+  test_alloc_zero_length ();
+  test_float_alloc_zero_length ();
+  test_long_double_alloc_zero_length ();
+  test_ulong_alloc_zero_length ();
+  test_long_alloc_zero_length ();
+  test_uint_alloc_zero_length ();
+  test_int_alloc_zero_length ();
+  test_ushort_alloc_zero_length ();
+  test_short_alloc_zero_length ();
+  test_uchar_alloc_zero_length ();
+  test_char_alloc_zero_length ();
+  test_complex_alloc_zero_length ();
+  test_complex_float_alloc_zero_length ();
+  test_complex_long_double_alloc_zero_length ();
+
+  test_calloc_zero_length ();
+  test_float_calloc_zero_length ();
+  test_long_double_calloc_zero_length ();
+  test_ulong_calloc_zero_length ();
+  test_long_calloc_zero_length ();
+  test_uint_calloc_zero_length ();
+  test_int_calloc_zero_length ();
+  test_ushort_calloc_zero_length ();
+  test_short_calloc_zero_length ();
+  test_uchar_calloc_zero_length ();
+  test_char_calloc_zero_length ();
+  test_complex_calloc_zero_length ();
+  test_complex_float_calloc_zero_length ();
+  test_complex_long_double_calloc_zero_length ();
 
   exit (gsl_test_summary ());
 }
