@@ -1,6 +1,6 @@
 /* normal.c
  * 
- * Copyright (C) 2015 Patrick Alken
+ * Copyright (C) 2015, 2016 Patrick Alken
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,16 +24,27 @@
 #include <gsl/gsl_linalg.h>
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_blas.h>
+#include <gsl/gsl_eigen.h>
+#include <gsl/gsl_multifit.h>
 #include <gsl/gsl_multilarge.h>
+#include <gsl/gsl_permutation.h>
 
 typedef struct
 {
-  size_t p;             /* number of columns of LS matrix */
-  gsl_matrix *ATA;      /* A^T A, p-by-p */
-  gsl_vector *ATb;      /* A^T b, p-by-1 */
-  double normb;         /* || b || */
-  gsl_matrix *work_ATA; /* workspace for chol(ATA), p-by-p */
-  gsl_vector *workp;    /* workspace size p */
+  size_t p;              /* number of columns of LS matrix */
+  gsl_matrix *ATA;       /* A^T A, p-by-p */
+  gsl_vector *ATb;       /* A^T b, p-by-1 */
+  double normb;          /* || b || */
+  gsl_matrix *work_ATA;  /* workspace for chol(ATA), p-by-p */
+  gsl_permutation *perm; /* permutation vector */
+  gsl_vector *workp;     /* workspace size p */
+  gsl_vector *work3p;    /* workspace size 3*p */
+  gsl_vector *D;         /* scale factors for ATA, size p */
+  gsl_vector *c;         /* solution vector for L-curve */
+  int eigen;             /* 1 if eigenvalues computed */
+  double eval_min;       /* minimum eigenvalue */
+  double eval_max;       /* maximum eigenvalue */
+  gsl_eigen_symm_workspace *eigen_p;
 } normal_state_t;
 
 static void *normal_alloc(const size_t p);
@@ -51,10 +62,9 @@ static int normal_solve_system(const double lambda, gsl_vector * x,
                                normal_state_t *state);
 static int normal_solve_cholesky(gsl_matrix * ATA, const gsl_vector * ATb,
                                  gsl_vector * x, normal_state_t *state);
-static int normal_solve_QR(gsl_matrix * ATA, const gsl_vector * ATb,
-                           gsl_vector * x, normal_state_t *state);
-static int normal_copy_lower(gsl_matrix * dest, const gsl_matrix * src);
-static int normal_copy_lowup(gsl_matrix * A);
+static int normal_calc_norms(const gsl_vector *x, double *rnorm,
+                             double *snorm, normal_state_t *state);
+static int normal_eigen(normal_state_t *state);
 
 /*
 normal_alloc()
@@ -106,6 +116,20 @@ normal_alloc(const size_t p)
       GSL_ERROR_NULL("failed to allocate ATb vector", GSL_ENOMEM);
     }
 
+  state->perm = gsl_permutation_alloc(p);
+  if (state->perm == NULL)
+    {
+      normal_free(state);
+      GSL_ERROR_NULL("failed to allocate perm", GSL_ENOMEM);
+    }
+
+  state->D = gsl_vector_alloc(p);
+  if (state->D == NULL)
+    {
+      normal_free(state);
+      GSL_ERROR_NULL("failed to allocate D vector", GSL_ENOMEM);
+    }
+
   state->workp = gsl_vector_alloc(p);
   if (state->workp == NULL)
     {
@@ -113,6 +137,29 @@ normal_alloc(const size_t p)
       GSL_ERROR_NULL("failed to allocate temporary ATb vector", GSL_ENOMEM);
     }
 
+  state->work3p = gsl_vector_alloc(3 * p);
+  if (state->work3p == NULL)
+    {
+      normal_free(state);
+      GSL_ERROR_NULL("failed to allocate work3p", GSL_ENOMEM);
+    }
+
+  state->c = gsl_vector_alloc(p);
+  if (state->c == NULL)
+    {
+      normal_free(state);
+      GSL_ERROR_NULL("failed to allocate c vector", GSL_ENOMEM);
+    }
+
+  state->eigen_p = gsl_eigen_symm_alloc(p);
+  if (state->eigen_p == NULL)
+    {
+      normal_free(state);
+      GSL_ERROR_NULL("failed to allocate eigen workspace", GSL_ENOMEM);
+    }
+
+  normal_reset(state);
+
   return state;
 }
 
@@ -130,9 +177,24 @@ normal_free(void *vstate)
   if (state->ATb)
     gsl_vector_free(state->ATb);
 
+  if (state->perm)
+    gsl_permutation_free(state->perm);
+
+  if (state->D)
+    gsl_vector_free(state->D);
+
   if (state->workp)
     gsl_vector_free(state->workp);
 
+  if (state->work3p)
+    gsl_vector_free(state->work3p);
+
+  if (state->c)
+    gsl_vector_free(state->c);
+
+  if (state->eigen_p)
+    gsl_eigen_symm_free(state->eigen_p);
+
   free(state);
 }
 
@@ -144,6 +206,9 @@ normal_reset(void *vstate)
   gsl_matrix_set_zero(state->ATA);
   gsl_vector_set_zero(state->ATb);
   state->normb = 0.0;
+  state->eigen = 0;
+  state->eval_min = 0.0;
+  state->eval_max = 0.0;
 
   return GSL_SUCCESS;
 }
@@ -225,7 +290,6 @@ normal_solve(const double lambda, gsl_vector * x,
   else
     {
       int status;
-      double r2;
 
       /* solve system (A^T A) x = A^T b */
       status = normal_solve_system(lambda, x, state);
@@ -234,22 +298,8 @@ normal_solve(const double lambda, gsl_vector * x,
           GSL_ERROR("failed to solve normal equations", status);
         }
 
-      /* compute solution norm ||x|| */
-      *snorm = gsl_blas_dnrm2(x);
-
-      /* compute residual norm ||b - Ax|| */
-
-      /* compute: A^T A x - 2 A^T b */
-      gsl_vector_memcpy(state->workp, state->ATb);
-      gsl_blas_dsymv(CblasLower, 1.0, state->ATA, x, -2.0, state->workp);
-
-      /* compute: x^T A^T A x - 2 x^T A^T b */
-      gsl_blas_ddot(x, state->workp, &r2);
-
-      /* add b^T b */
-      r2 += state->normb * state->normb;
-
-      *rnorm = sqrt(r2);
+      /* compute residual norm ||y - X c|| and solution norm ||x|| */
+      normal_calc_norms(x, rnorm, snorm, state);
 
       return GSL_SUCCESS;
     }
@@ -258,8 +308,15 @@ normal_solve(const double lambda, gsl_vector * x,
 static int
 normal_rcond(double * rcond, void * vstate)
 {
-  *rcond = 0.0;
-  return GSL_SUCCESS;
+  normal_state_t *state = (normal_state_t *) vstate;
+  int status = GSL_SUCCESS;
+  double rcond_ATA;
+
+  status = gsl_linalg_pcholesky_rcond(state->work_ATA, state->perm, &rcond_ATA, state->work3p);
+  if (status == GSL_SUCCESS)
+    *rcond = sqrt(rcond_ATA);
+
+  return status;
 }
 
 /*
@@ -278,6 +335,50 @@ static int
 normal_lcurve(gsl_vector * reg_param, gsl_vector * rho,
               gsl_vector * eta, void * vstate)
 {
+  normal_state_t *state = (normal_state_t *) vstate;
+  int status;
+  double smin, smax; /* minimum/maximum singular values */
+  size_t i;
+
+  if (state->eigen == 0)
+    {
+      status = normal_eigen(state);
+      if (status)
+        return status;
+    }
+
+  if (state->eval_max < 0.0)
+    {
+      GSL_ERROR("matrix is not positive definite", GSL_EDOM);
+    }
+
+  /* compute singular values which are sqrts of eigenvalues */
+  smax = sqrt(state->eval_max);
+  if (state->eval_min > 0.0)
+    smin = sqrt(state->eval_min);
+  else
+    smin = 0.0;
+
+  /* compute vector of regularization parameters */
+  gsl_multifit_linear_lreg(smin, smax, reg_param);
+
+  /* solve normal equations for each regularization parameter */
+  for (i = 0; i < reg_param->size; ++i)
+    {
+      double lambda = gsl_vector_get(reg_param, i);
+      double rnorm, snorm;
+
+      status = normal_solve_system(lambda, state->c, state);
+      if (status)
+        return status;
+
+      /* compute ||y - X c|| and ||c|| */
+      normal_calc_norms(state->c, &rnorm, &snorm, state);
+
+      gsl_vector_set(rho, i, rnorm);
+      gsl_vector_set(eta, i, snorm);
+    }
+
   return GSL_SUCCESS;
 }
 
@@ -287,8 +388,7 @@ normal_solve_system()
 
 (A^T A + lambda^2*I) x = A^T b
 
-First we try Cholesky decomposition. If that
-fails, try QR
+using LDL decomposition.
 
 Inputs: x     - (output) solution vector
         state - workspace
@@ -302,28 +402,15 @@ normal_solve_system(const double lambda, gsl_vector * x, normal_state_t *state)
   int status;
   const double lambda_sq = lambda * lambda;
   gsl_vector_view d = gsl_matrix_diagonal(state->work_ATA);
-  gsl_error_handler_t *err_handler;
 
   /* copy ATA matrix to temporary workspace and regularize */
-  normal_copy_lower(state->work_ATA, state->ATA);
+  gsl_matrix_tricpy('L', 1, state->work_ATA, state->ATA);
   gsl_vector_add_constant(&d.vector, lambda_sq);
 
-  /* turn off error handler in case Cholesky fails */
-  err_handler = gsl_set_error_handler_off();
-
-  /* try Cholesky decomposition first */
+  /* solve with LDL decomposition */
   status = normal_solve_cholesky(state->work_ATA, state->ATb, x, state);
   if (status)
-    {
-      /* restore ATA matrix and try QR decomposition */
-      normal_copy_lower(state->work_ATA, state->ATA);
-      gsl_vector_add_constant(&d.vector, lambda_sq);
-
-      status = normal_solve_QR(state->work_ATA, state->ATb, x, state);
-    }
-
-  /* restore error handler */
-  gsl_set_error_handler(err_handler);
+    return status;
 
   return status;
 }
@@ -334,76 +421,78 @@ normal_solve_cholesky(gsl_matrix * ATA, const gsl_vector * ATb,
 {
   int status;
 
-  /* compute Cholesky decomposition of A^T A */
-  status = gsl_linalg_cholesky_decomp(ATA);
+  status = gsl_linalg_pcholesky_decomp2(ATA, state->perm, state->D);
   if (status)
     return status;
 
-  status = gsl_linalg_cholesky_solve(ATA, ATb, x);
+  status = gsl_linalg_pcholesky_solve2(ATA, state->perm, state->D, ATb, x);
   if (status)
     return status;
 
   return GSL_SUCCESS;
 }
 
+/*
+normal_calc_norms()
+  Compute residual norm ||y - X c|| and solution
+norm ||c||
+
+Inputs: x     - solution vector
+        rnorm - (output) residual norm ||y - X c||
+        snorm - (output) solution norm ||c||
+        state - workspace
+*/
+
 static int
-normal_solve_QR(gsl_matrix * ATA, const gsl_vector * ATb,
-                gsl_vector * x, normal_state_t *state)
+normal_calc_norms(const gsl_vector *x, double *rnorm,
+                  double *snorm, normal_state_t *state)
+{
+  double r2;
+
+  /* compute solution norm ||x|| */
+  *snorm = gsl_blas_dnrm2(x);
+
+  /* compute residual norm ||b - Ax|| */
+
+  /* compute: A^T A x - 2 A^T b */
+  gsl_vector_memcpy(state->workp, state->ATb);
+  gsl_blas_dsymv(CblasLower, 1.0, state->ATA, x, -2.0, state->workp);
+
+  /* compute: x^T A^T A x - 2 x^T A^T b */
+  gsl_blas_ddot(x, state->workp, &r2);
+
+  /* add b^T b */
+  r2 += state->normb * state->normb;
+
+  *rnorm = sqrt(r2);
+
+  return GSL_SUCCESS;
+}
+
+/*
+normal_eigen()
+  Compute eigenvalues of A^T A matrix, which
+are stored in state->workp on output. Also,
+state->eval_min and state->eval_max are set
+to the minimum/maximum eigenvalues
+*/
+
+static int
+normal_eigen(normal_state_t *state)
 {
   int status;
 
-  /* copy lower triangle of ATA to upper */
-  normal_copy_lowup(ATA);
+  /* copy lower triangle of ATA to temporary workspace */
+  gsl_matrix_tricpy('L', 1, state->work_ATA, state->ATA);
 
-  status = gsl_linalg_QR_decomp(ATA, state->workp);
+  /* compute eigenvalues of ATA */
+  status = gsl_eigen_symm(state->work_ATA, state->workp, state->eigen_p);
   if (status)
     return status;
 
-  status = gsl_linalg_QR_solve(ATA, state->workp, ATb, x);
-  if (status)
-    return status;
+  gsl_vector_minmax(state->workp, &state->eval_min, &state->eval_max);
 
-  return GSL_SUCCESS;
-}
-
-/* copy lower triangle of src to dest, including diagonal */
-static int
-normal_copy_lower(gsl_matrix * dest, const gsl_matrix * src)
-{
-  const size_t src_size1 = src->size1;
-  const size_t src_tda = src->tda;
-  const size_t dest_tda = dest->tda;
-  size_t i, j;
-
-  for (i = 0; i < src_size1 ; i++)
-    {
-      for (j = 0; j <= i; j++)
-        {
-          dest->data[dest_tda * i + j] 
-            = src->data[src_tda * i + j];
-        }
-    }
-
-  return GSL_SUCCESS;
-}
-
-/* copy lower triangular part of matrix to upper */
-static int
-normal_copy_lowup(gsl_matrix * A)
-{
-  const size_t size1 = A->size1;
-  const size_t size2 = A->size2;
-  const size_t tda = A->tda;
-  size_t i, j;
-
-  for (i = 0; i < size1; ++i)
-    {
-      for (j = i + 1; j < size2; ++j)
-        {
-          A->data[tda * i + j] 
-            = A->data[tda * j + i];
-        }
-    }
+  state->eigen = 1;
 
   return GSL_SUCCESS;
 }
