@@ -4,7 +4,7 @@
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /* Runge-Kutta 8(9), Prince-Dormand 
@@ -264,7 +264,7 @@ rk8pd_apply (void *vstate,
 
       if (s != GSL_SUCCESS)
 	{
-	  return GSL_EBADFUNC;
+	  return s;
 	}
     }
 
@@ -277,7 +277,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -290,7 +290,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -303,7 +303,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -316,7 +316,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -329,7 +329,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -344,7 +344,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -359,7 +359,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -374,7 +374,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -390,7 +390,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -406,7 +406,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -422,7 +422,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -439,7 +439,7 @@ rk8pd_apply (void *vstate,
 
     if (s != GSL_SUCCESS)
       {
-	return GSL_EBADFUNC;
+	return s;
       }
   }
 
@@ -463,7 +463,7 @@ rk8pd_apply (void *vstate,
 	{
 	  /* Restore initial values */
 	  DBL_MEMCPY (y, y0, dim);
-	  return GSL_EBADFUNC;
+	  return s;
 	}
     }
 
