@@ -167,7 +167,7 @@ gsl_spmatrix_transpose_memcpy(gsl_spmatrix *dest, const gsl_spmatrix *src)
           size_t *ATi = dest->i;
           size_t *ATp = dest->p;
           double *ATd = dest->data;
-          size_t *w = (size_t *) dest->work;
+          size_t *w = dest->work_sze;
           size_t p, j;
 
           /* initialize to 0 */
@@ -203,7 +203,7 @@ gsl_spmatrix_transpose_memcpy(gsl_spmatrix *dest, const gsl_spmatrix *src)
           size_t *ATj = dest->i;
           size_t *ATp = dest->p;
           double *ATd = dest->data;
-          size_t *w = (size_t *) dest->work;
+          size_t *w = dest->work_sze;
           size_t p, i;
 
           /* initialize to 0 */
