@@ -635,41 +635,51 @@ FUNCTION (test, file) (size_t stride, size_t N)
 {
   TYPE (gsl_vector) * v = FUNCTION (create, vector) (stride, N);
   TYPE (gsl_vector) * w = FUNCTION (create, vector) (stride, N);
-
   size_t i;
 
-  FILE *f = tmpfile();
+#ifdef NO_INLINE
+  char filename[] = "test_static.dat";
+#else
+  char filename[] = "test.dat";
+#endif
 
-  /* write file */
+  {
+    /* write file */
+    FILE *f = fopen(filename, "wb");
 
-  for (i = 0; i < N; i++)
-    {
-      BASE x = ZERO;
-      GSL_REAL (x) = (ATOMIC)(N - i);
-      GSL_IMAG (x) = (ATOMIC)(N - i + 1);
-      FUNCTION (gsl_vector, set) (v, i, x);
-    };
+    for (i = 0; i < N; i++)
+      {
+        BASE x = ZERO;
+        GSL_REAL (x) = (ATOMIC)(N - i);
+        GSL_IMAG (x) = (ATOMIC)(N - i + 1);
+        FUNCTION (gsl_vector, set) (v, i, x);
+      };
 
-  FUNCTION (gsl_vector, fwrite) (f, v);
+    FUNCTION (gsl_vector, fwrite) (f, v);
 
-  /* read file */
+    fclose(f);
+  }
 
-  rewind(f);
-  FUNCTION (gsl_vector, fread) (f, w);
+  {
+    /* read file */
+    FILE *f = fopen(filename, "rb");
 
-  status = 0;
-  for (i = 0; i < N; i++)
-    {
-      if (w->data[2 * i * stride] != (ATOMIC) (N - i) || w->data[2 * i * stride + 1] != (ATOMIC) (N - i + 1))
-        status = 1;
-    };
+    FUNCTION (gsl_vector, fread) (f, w);
 
-  fclose (f);
+    status = 0;
+    for (i = 0; i < N; i++)
+      {
+        if (w->data[2 * i * stride] != (ATOMIC) (N - i) || w->data[2 * i * stride + 1] != (ATOMIC) (N - i + 1))
+          status = 1;
+      };
+
+    gsl_test (status, NAME (gsl_vector) "_write and read work");
+
+    fclose (f);
+  }
 
   FUNCTION (gsl_vector, free) (v);
   FUNCTION (gsl_vector, free) (w);
-
-  gsl_test (status, NAME (gsl_vector) "_write and read work");
 }
 
 #if USES_LONGDOUBLE && ! HAVE_PRINTF_LONGDOUBLE
@@ -680,41 +690,51 @@ FUNCTION (test, text) (size_t stride, size_t N)
 {
   TYPE (gsl_vector) * v = FUNCTION (create, vector) (stride, N);
   TYPE (gsl_vector) * w = FUNCTION (create, vector) (stride, N);
-
   size_t i;
 
-  FILE *f = tmpfile();
+#ifdef NO_INLINE
+  char filename[] = "test_static.dat";
+#else
+  char filename[] = "test.dat";
+#endif
 
-  /* write file */
+  {
+    /* write file */
+    FILE *f = fopen(filename, "w");
 
-  for (i = 0; i < N; i++)
-    {
-      BASE x;
-      GSL_REAL (x) = (ATOMIC)i;
-      GSL_IMAG (x) = (ATOMIC)(i + 1);
-      FUNCTION (gsl_vector, set) (v, i, x);
-    };
+    for (i = 0; i < N; i++)
+      {
+        BASE x;
+        GSL_REAL (x) = (ATOMIC)i;
+        GSL_IMAG (x) = (ATOMIC)(i + 1);
+        FUNCTION (gsl_vector, set) (v, i, x);
+      };
 
-  FUNCTION (gsl_vector, fprintf) (f, v, OUT_FORMAT);
+    FUNCTION (gsl_vector, fprintf) (f, v, OUT_FORMAT);
 
-  /* read file */
+    fclose(f);
+  }
 
-  rewind(f);
-  FUNCTION (gsl_vector, fscanf) (f, w);
+  {
+    /* read file */
+    FILE *f = fopen(filename, "r");
 
-  status = 0;
-  for (i = 0; i < N; i++)
-    {
-      if (w->data[2 * i * stride] != (ATOMIC) i || w->data[2 * i * stride + 1] != (ATOMIC) (i + 1))
-        status = 1;
-    };
+    FUNCTION (gsl_vector, fscanf) (f, w);
 
-  fclose (f);
+    status = 0;
+    for (i = 0; i < N; i++)
+      {
+        if (w->data[2 * i * stride] != (ATOMIC) i || w->data[2 * i * stride + 1] != (ATOMIC) (i + 1))
+          status = 1;
+      };
+
+    gsl_test (status, NAME (gsl_vector) "_fprintf and fscanf");
+
+    fclose (f);
+  }
 
   FUNCTION (gsl_vector, free) (v);
   FUNCTION (gsl_vector, free) (w);
-
-  gsl_test (status, NAME (gsl_vector) "_fprintf and fscanf");
 }
 #endif
 
