@@ -715,35 +715,45 @@ FUNCTION (test, file) (size_t stride, size_t N)
 {
   TYPE (gsl_vector) * v = FUNCTION (create, vector) (stride, N);
   TYPE (gsl_vector) * w = FUNCTION (create, vector) (stride, N);
-
   size_t i;
 
-  FILE *f = tmpfile();
+#ifdef NO_INLINE
+  char filename[] = "test_static.dat";
+#else
+  char filename[] = "test.dat";
+#endif
 
-  /* write file */
+  {
+    /* write file */
+    FILE *f = fopen(filename, "wb");
 
-  for (i = 0; i < N; i++)
-    {
-      FUNCTION (gsl_vector, set) (v, i, (ATOMIC) (N - i));
-    };
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) (N - i));
+      };
 
-  FUNCTION (gsl_vector, fwrite) (f, v);
+    FUNCTION (gsl_vector, fwrite) (f, v);
 
-  /* read file */
+    fclose(f);
+  }
 
-  rewind(f);
-  FUNCTION (gsl_vector, fread) (f, w);
+  {
+    /* read file */
+    FILE *f = fopen(filename, "rb");
 
-  status = 0;
-  for (i = 0; i < N; i++)
-    {
-      if (w->data[i*stride] != (ATOMIC) (N - i))
-        status = 1;
-    };
+    FUNCTION (gsl_vector, fread) (f, w);
 
-  TEST (status, "_write and read");
+    status = 0;
+    for (i = 0; i < N; i++)
+      {
+        if (w->data[i*stride] != (ATOMIC) (N - i))
+          status = 1;
+      };
 
-  fclose(f);
+    TEST (status, "_write and read");
+
+    fclose(f);
+  }
 
   FUNCTION (gsl_vector, free) (v);      /* free whatever is in v */
   FUNCTION (gsl_vector, free) (w);      /* free whatever is in w */
@@ -757,35 +767,45 @@ FUNCTION (test, text) (size_t stride, size_t N)
 {
   TYPE (gsl_vector) * v = FUNCTION (create, vector) (stride, N);
   TYPE (gsl_vector) * w = FUNCTION (create, vector) (stride, N);
-
   size_t i;
 
-  FILE *f = tmpfile();
+#ifdef NO_INLINE
+  char filename[] = "test_static.dat";
+#else
+  char filename[] = "test.dat";
+#endif
 
-  /* write file */
+  {
+    /* write file */
+    FILE *f = fopen(filename, "w");
 
-  for (i = 0; i < N; i++)
-    {
-      FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
-    };
+    for (i = 0; i < N; i++)
+      {
+        FUNCTION (gsl_vector, set) (v, i, (ATOMIC) i);
+      };
 
-  FUNCTION (gsl_vector, fprintf) (f, v, OUT_FORMAT);
+    FUNCTION (gsl_vector, fprintf) (f, v, OUT_FORMAT);
 
-  /* read file */
+    fclose(f);
+  }
 
-  rewind(f);
-  FUNCTION (gsl_vector, fscanf) (f, w);
+  {
+    /* read file */
+    FILE *f = fopen(filename, "r");
 
-  status = 0;
-  for (i = 0; i < N; i++)
-    {
-      if (w->data[i*stride] != (ATOMIC) i)
-        status = 1;
-    };
+    FUNCTION (gsl_vector, fscanf) (f, w);
 
-  gsl_test (status, NAME (gsl_vector) "_fprintf and fscanf");
+    status = 0;
+    for (i = 0; i < N; i++)
+      {
+        if (w->data[i*stride] != (ATOMIC) i)
+          status = 1;
+      };
 
-  fclose (f);
+    gsl_test (status, NAME (gsl_vector) "_fprintf and fscanf");
+
+    fclose (f);
+  }
 
   FUNCTION (gsl_vector, free) (v);
   FUNCTION (gsl_vector, free) (w);
