@@ -1,10 +1,10 @@
 /* vector/view_source.c
  * 
- * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Gerard Jungman, Brian Gough
+ * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001, 2007 Gerard Jungman, Brian Gough
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -22,12 +22,6 @@ FUNCTION(gsl_vector, view_array) (QUALIFIER ATOMIC * base, size_t n)
 {
   QUALIFIED_VIEW(_gsl_vector,view) view = NULL_VECTOR_VIEW;
 
-  if (n == 0)
-    {
-      GSL_ERROR_VAL ("vector length n must be positive integer", 
-                     GSL_EINVAL, view);
-    }
-
   {
     TYPE(gsl_vector) v = NULL_VECTOR;
 
@@ -49,12 +43,6 @@ FUNCTION(gsl_vector, view_array_with_stride) (QUALIFIER ATOMIC * base,
 {
   QUALIFIED_VIEW(_gsl_vector,view) view = NULL_VECTOR_VIEW;
 
-  if (n == 0)
-    {
-      GSL_ERROR_VAL ("vector length n must be positive integer", 
-                     GSL_EINVAL, view);
-    }
-
   if (stride == 0)
     {
       GSL_ERROR_VAL ("stride must be positive integer", 
